@@ -28,7 +28,7 @@ from cryptography.hazmat.primitives.ciphers.modes import CTR
 from cryptography.hazmat.backends import default_backend
 from cryptography.exceptions import InvalidSignature
 
-__version__ = '1.11.1'
+__version__ = '1.11.2'
 
 def main():
   try:
@@ -39,7 +39,7 @@ def main():
     prog = os.path.basename(sys.argv[0])
     jinjafx_usage = '-t <template.j2> [-d <data.csv>] [-g <vars.yml>]\n'
     jinjafx_usage += (' ' * (len(prog) + 3)) + '-dt <dt.yml> [-ds <dataset>] [-g <vars.yml>]\n'
-    jinjafx_usage += (' ' * (len(prog) + 3)) + '-encrypt/-decrypt [file1[ file2[ ...]]]\n'
+    jinjafx_usage += (' ' * (len(prog) + 3)) + '-encrypt/-decrypt [file1] [file2] [...]\n'
     jinjafx_usage += '''
 
     -t <template.j2>           - specify a Jinja2 template
@@ -709,7 +709,7 @@ class JinjaFx():
 
 
   def __jfx_lookup(self, method, variable, default=None):
-    if method == 'vars':
+    if method == 'vars' or method == 'ansible.builtin.vars':
       if variable in self.__g_vars:
         return self.__g_vars[variable]
 
